@@ -1,6 +1,7 @@
 import os
 from datetime import date
 from pathlib import Path
+import webbrowser
 
 import click
 
@@ -9,6 +10,7 @@ import imagesize
 
 from .cover_page_ams import create_cover_page
 from .cover_page_project import create_project_cover
+from .testdir import listdirs
 
 font_dir = Path('X:/9999_BID_AMS/AMS-VFB_Fonts')
 
@@ -46,6 +48,9 @@ def main():
     project_path = Path(get_cwd())
 
     click.echo(f"🕵️‍♀️ We're running in {str(project_path)}")
+
+    selection = listdirs(project_path)
+
     project_name = input("🙏 Type in the project name: ")
 
     create_cover_page(pdf)
@@ -56,25 +61,11 @@ def main():
     if len(proj_number) != 4:
         click.secho('probber')
 
-    stills = project_path.joinpath('Test_Stills')
-    if not stills.is_dir():
-        click.secho(
-            f"You need a folder called 'Test_Stills' inside {str(project_path)}",
-            fg='yellow')
-        return
-
-    pov = stills.joinpath("POV")
-
-    if not pov.is_dir():
-        click.secho(
-            f"You need a folder called 'POV' inside {stills}",
-            fg='yellow')
-        return
-
-    files = [x for x in pov.iterdir() if x.is_file()]
+    files = [x for x in selection.iterdir() if x.is_file()
+             and x.suffix == ".jpg"]
     for f in files:
         pdf.add_page()
-        camname = f.stem
+        camname = f.stem.replace('_', ' ')
         pdf.set_font('Arial', 'B', size=18)
         pdf.cell(w=50, h=10, txt=project_name.upper(), align='R', ln=2)
         pdf.set_font('Arial', size=14)
@@ -98,4 +89,6 @@ def main():
 
     # datum = date.today().strftime("%Y%m%d")
     # dirname = os.path.join(mv, f'{max(mvs)+1}_{datum}_pov_brief')
-    pdf.output(os.path.join(mv, 'pov_brief.pdf'), 'F')
+    dest = mv.joinpath('pov_brief.pdf')
+    pdf.output(dest, 'F')
+    webbrowser.open(dest)
